@@ -47,7 +47,7 @@ class ConstructList(list, Container, cfdm.Container):
     """
 
     def __init__(self, constructs=None):
-        """**Initialization**
+        """**Initialisation**
 
         :Parameters:
 
@@ -96,14 +96,7 @@ class ConstructList(list, Container, cfdm.Container):
         See `_docstring_method_exclusions` for details.
 
         """
-        return (
-            "append",
-            "extend",
-            "insert",
-            "pop",
-            "reverse",
-            "clear",
-        )
+        return ("append", "extend", "insert", "pop", "reverse", "clear")
 
     # ----------------------------------------------------------------
     # Overloaded list methods
@@ -118,7 +111,7 @@ class ConstructList(list, Container, cfdm.Container):
             `{{class}}`
                 The concatenation of the list and another sequence.
 
-        **Examples:**
+        **Examples**
 
         >>> h = f + g
         >>> f += g
@@ -153,7 +146,7 @@ class ConstructList(list, Container, cfdm.Container):
             `{{class}}`
                 The list added to itself *n* times.
 
-        **Examples:**
+        **Examples**
 
         >>> h = f * 2
         >>> f *= 2
@@ -187,7 +180,7 @@ class ConstructList(list, Container, cfdm.Container):
             `{{class}}`
                 Slice of the list from *i* to *j*.
 
-        **Examples:**
+        **Examples**
 
         >>> g = f[0:1]
         >>> g = f[1:-4]
@@ -208,7 +201,7 @@ class ConstructList(list, Container, cfdm.Container):
                 construct element is returned. If *index* is a slice
                 then a new {{class}} is returned, which may be empty.
 
-        **Examples:**
+        **Examples**
 
         >>> g = f[0]
         >>> g = f[-1:-4:-1]
@@ -261,7 +254,7 @@ class ConstructList(list, Container, cfdm.Container):
 
             `None`
 
-        **Examples:**
+        **Examples**
 
         >>> f.close()
 
@@ -279,7 +272,7 @@ class ConstructList(list, Container, cfdm.Container):
 
         .. seealso:: `list.count`
 
-        **Examples:**
+        **Examples**
 
         >>> f = cf.{{class}}([a, b, c, a])
         >>> f.count(a)
@@ -380,7 +373,7 @@ class ConstructList(list, Container, cfdm.Container):
             `{{class}}`
                 The deep copy.
 
-        **Examples:**
+        **Examples**
 
         >>> g = f.copy()
         >>> g is f
@@ -397,7 +390,7 @@ class ConstructList(list, Container, cfdm.Container):
         """
         return type(self)([f.copy(data=data) for f in self])
 
-    @_deprecated_kwarg_check("traceback")
+    @_deprecated_kwarg_check("traceback", version="3.0.0", removed_at="4.0.0")
     @_manage_log_level_via_verbosity
     def equals(
         self,
@@ -407,7 +400,7 @@ class ConstructList(list, Container, cfdm.Container):
         verbose=None,
         ignore_data_type=False,
         ignore_fill_value=False,
-        ignore_properties=(),
+        ignore_properties=None,
         ignore_compression=False,
         ignore_type=False,
         ignore=(),
@@ -464,25 +457,25 @@ class ConstructList(list, Container, cfdm.Container):
 
             {{verbose: `int` or `str` or `None`, optional}}
 
-            ignore_properties: sequence of `str`, optional
-                The names of properties of the field construct (not
-                the TODO metadata constructs) to omit from the
-                comparison. Note that the "Conventions" property is
-                always omitted by default.
+            {{ignore_properties: (sequence of) `str`, optional}}
 
             {{ignore_data_type: `bool`, optional}}
 
             {{ignore_compression: `bool`, optional}}
 
             unordered: `bool`, optional
-                TODO
+                If True then test that the lists contain equal
+                constructs in any relative order. By default, construct
+                order matters for the list comparison, such that each
+                construct is tested for equality with the construct
+                at the corresponding position in the list, pair-wise.
 
         :Returns:
 
             `bool`
                 Whether the two lists are equal.
 
-        **Examples:**
+        **Examples**
 
         >>> fl.equals(fl)
         True
@@ -500,6 +493,8 @@ class ConstructList(list, Container, cfdm.Container):
                 "equals",
                 {"ignore": ignore},
                 "Use keyword 'ignore_properties' instead.",
+                version="3.0.0",
+                removed_at="4.0.0",
             )  # pragma: no cover
 
         # Check for object identity
@@ -660,7 +655,7 @@ class ConstructList(list, Container, cfdm.Container):
             `{{class}}`
                 The matching constructs.
 
-        **Examples:**
+        **Examples**
 
         See `{{package}}.{{class}}.match_by_identity`
 
@@ -693,13 +688,17 @@ class ConstructList(list, Container, cfdm.Container):
                 "Use methods 'select_by_units', 'select_by_construct', "
                 "'select_by_properties', 'select_by_naxes', 'select_by_rank' "
                 "instead.",
+                version="3.0.0",
+                removed_at="4.0.0",
             )  # pragma: no cover
 
         if identities and isinstance(identities[0], (list, tuple, set)):
             _DEPRECATION_ERROR(
                 f"Use of a {identities[0].__class__.__name__!r} for "
                 "identities has been deprecated. Use the * operator to "
-                "unpack the arguments instead."
+                "unpack the arguments instead.",
+                version="3.0.0",
+                removed_at="4.0.0",
             )  # pragma: no cover
 
         for i in identities:
@@ -707,7 +706,9 @@ class ConstructList(list, Container, cfdm.Container):
                 _DEPRECATION_ERROR_DICT(
                     "Use methods 'select_by_units', 'select_by_construct', "
                     "'select_by_properties', 'select_by_naxes', "
-                    "'select_by_rank' instead."
+                    "'select_by_rank' instead.",
+                    version="3.0.0",
+                    removed_at="4.0.0",
                 )  # pragma: no cover
 
             if isinstance(i, str) and ":" in i:
@@ -721,7 +722,9 @@ class ConstructList(list, Container, cfdm.Container):
                     _DEPRECATION_ERROR(
                         f"The identity format {i!r} has been deprecated at "
                         f"version 3.0.0. Try {i.replace(':', '=', 1)!r} "
-                        "instead."
+                        "instead.",
+                        version="3.0.0",
+                        removed_at="4.0.0",
                     )  # pragma: no cover
 
         return self.select_by_identity(*identities)
