@@ -1,17 +1,20 @@
-import logging
-from functools import reduce
-from operator import mul as operator_mul
+from math import prod
 
 import cfdm
-import numpy as np
 
 from . import mixin
+from .auxiliarycoordinate import AuxiliaryCoordinate
 from .constructs import Constructs
 from .data import Data
 from .decorators import _inplace_enabled, _inplace_enabled_define_and_cleanup
-from .functions import _DEPRECATION_ERROR_ARG, parse_indices
-
-logger = logging.getLogger(__name__)
+from .dimensioncoordinate import DimensionCoordinate
+from .domainaxis import DomainAxis
+from .functions import (
+    _DEPRECATION_ERROR_ARG,
+    _DEPRECATION_ERROR_METHOD,
+    indices_shape,
+    parse_indices,
+)
 
 _empty_set = set()
 
@@ -74,8 +77,11 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
     def __new__(cls, *args, **kwargs):
         """Creates a new Domain instance."""
         instance = super().__new__(cls)
-        instance._Data = Data
         instance._Constructs = Constructs
+        instance._Data = Data
+        instance._DomainAxis = DomainAxis
+        instance._DimensionCoordinate = DimensionCoordinate
+        instance._AuxiliaryCoordinate = AuxiliaryCoordinate
         return instance
 
     def __repr__(self):
@@ -120,15 +126,16 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
         if not domain_axes:
             return 0
 
-        return reduce(
-            operator_mul,
-            [domain_axis.get_size(0) for domain_axis in domain_axes.values()],
-            1,
+        return prod(
+            [domain_axis.get_size(0) for domain_axis in domain_axes.values()]
         )
 
     def close(self):
         """Close all files referenced by the domain construct.
 
+        Deprecated at version 3.14.0. All files are now
+        automatically closed when not being accessed.
+
         Note that a closed file will be automatically reopened if its
         contents are subsequently required.
 
@@ -136,179 +143,18 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
 
             `None`
 
-        **Examples:**
+        **Examples**
 
         >>> d.close()
 
         """
-        # TODODASK - is this still needed?
-
-        self.constructs.close()
-
-    #    def cyclic(
-    #        self, *identity, iscyclic=True, period=None, config={}, **filter_kwargs
-    #    ):
-    #        """Set the cyclicity of an axis.
-    #
-    #        .. versionadded:: 3.11.0
-    #
-    #        .. seealso:: `autocyclic`, `domain_axis`, `iscyclic`
-    #
-    #        :Parameters:
-    #
-    #            identity, filter_kwargs: optional
-    #                Select the unique domain axis construct returned by
-    #                ``f.domain_axis(*identity, **filter_kwargs)``. See
-    #                `domain_axis` for details.
-    #
-    #            iscyclic: `bool`, optional
-    #                If False then the axis is set to be non-cyclic. By
-    #                default the selected axis is set to be cyclic.
-    #
-    #            period: optional
-    #                The period for a dimension coordinate construct which
-    #                spans the selected axis. May be any numeric scalar
-    #                object that can be converted to a `Data` object (which
-    #                includes numpy array and `Data` objects). The absolute
-    #                value of *period* is used. If *period* has units then
-    #                they must be compatible with those of the dimension
-    #                coordinates, otherwise it is assumed to have the same
-    #                units as the dimension coordinates.
-    #
-    #            config: `dict`
-    #                Additional parameters for optimizing the
-    #                operation. See the code for details.
-    #
-    #        :Returns:
-    #
-    #            `set`
-    #                The construct keys of the domain axes which were cyclic
-    #                prior to the new setting, or the current cyclic domain
-    #                axes if no axis was specified.
-    #
-    #        **Examples:**
-    #
-    #        >>> f.cyclic()
-    #        set()
-    #        >>> f.cyclic('X', period=360)
-    #        set()
-    #        >>> f.cyclic()
-    #        {'domainaxis2'}
-    #        >>> f.cyclic('X', iscyclic=False)
-    #        {'domainaxis2'}
-    #        >>> f.cyclic()
-    #        set()
-    #
-    #        """
-    #        cyclic = self._cyclic
-    #        old = cyclic.copy()
-    #
-    #        if identity is None:
-    #            return old
-    #
-    #        axis = self.domain_axis(identity, key=True)
-    #
-    #        if iscyclic:
-    #            dim = self.dimension_coordinate(axis, default=None)
-    #            if dim is not None:
-    #                if period is not None:
-    #                    dim.period(period)
-    #                elif dim.period() is None:
-    #                    raise ValueError(
-    #                        "A cyclic dimension coordinate must have a period"
-    #                    )
-    #
-    #        # Never change _cyclic in-place
-    #        self._cyclic = cyclic.union((axis,))
-    #
-    #        return old
-    #
-    #    def domain_axis(self, identity=None, key=False, item=False,
-    #                    default=ValueError()):
-    #        """Return a domain axis construct, or its key.
-    #
-    #        .. versionadded:: 3.11.0
-    #
-    #        .. seealso:: `construct`, `auxiliary_coordinate`, `cell_measure`,
-    #                     `cell_method`, `coordinate`, `coordinate_reference`,
-    #                     `dimension_coordinate`, `domain_ancillary`,
-    #                     `domain_axes`, `field_ancillary`
-    #
-    #        :Parameters:
-    #
-    #            identity: optional
-    #                Select the domain axis construct.
-    #
-    #                {{domain axis selection}}
-    #
-    #                If *identity is `None` (the default) then the unique
-    #                domain axis construct is selected when there is only one
-    #                of them.
-    #
-    #                *Parameter example:*
-    #                  ``identity='time'``
-    #
-    #                *Parameter example:*
-    #                  ``identity='domainaxis2'``
-    #
-    #                *Parameter example:*
-    #                  ``identity='ncdim%y'``
-    #
-    #            key: `bool`, optional
-    #                If True then return the selected construct key. By
-    #                default the construct itself is returned.
-    #
-    #            default: optional
-    #                Return the value of the *default* parameter if a construct
-    #                can not be found.
-    #
-    #                {{default Exception}}
-    #
-    #        :Returns:
-    #
-    #            `DomainAxis` or `str`
-    #                The selected domain axis construct, or its key.
-    #
-    #        **Examples:**
-    #
-    #        """
-    #        c = self.domain_axes(identity)
-    #
-    #        n = len(c)
-    #        if n == 1:
-    #            k, construct = c.popitem()
-    #            if key:
-    #                return k
-    #
-    #            if item:
-    #                return k, construct
-    #
-    #            return construct
-    #        elif n > 1:
-    #            if default is None:
-    #                return default
-    #
-    #            return self._default(
-    #                default,
-    #                f"{self.__class__.__name__}.{_method}() can't return {n} "
-    #                "constructs",
-    #            )
-    #
-    #        # identity is not a unique domain axis construct identity
-    #        da_key = self.domain_axis_key(identity, default=None)
-    #        if da_key is None:
-    #            if default is None:
-    #                return default
-    #
-    #            return self._default(
-    #                default,
-    #                message=f"No domain axis found from identity {identity!r}",
-    #            )
-    #
-    #        if key:
-    #            return da_key
-    #
-    #        return self.constructs[da_key]
+        _DEPRECATION_ERROR_METHOD(
+            self,
+            "close",
+            "All files are now automatically closed when not being accessed.",
+            version="3.14.0",
+            removed_at="5.0.0",
+        )  # pragma: no cover
 
     @_inplace_enabled(default=False)
     def flip(self, axes=None, inplace=False):
@@ -337,7 +183,7 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
                 The domain with flipped axes, or `None` if the operation
                 was in-place.
 
-        **Examples:**
+        **Examples**
 
         >>> d = cf.example_field(0).domain
         >>> print(d)
@@ -406,7 +252,7 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
                 The value of the *default* parameter, if an exception
                 has not been raised.
 
-        **Examples:**
+        **Examples**
 
         >>> d = cf.example_domain(0)
         >>> print(d.get_data(None))
@@ -424,96 +270,6 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
             default, message=f"{self.__class__.__name__} has no data"
         )
 
-    def get_data_axes(self, identity, default=ValueError()):
-        """Return the keys of the domain axis constructs spanned by the
-        data of a metadata construct.
-
-        .. versionadded:: 3.11.0
-
-        .. seealso:: `del_data_axes`, `has_data_axes`, `set_data_axes`
-
-        :Parameters:
-
-            identity: optional
-                Select the construct by one of
-
-                * A metadata construct identity.
-
-                  {{construct selection identity}}
-
-                * The key of a metadata construct
-
-                * `None`. This is the default, which selects the metadata
-                  construct when there is only one of them.
-
-                *Parameter example:*
-                  ``identity='latitude'``
-
-                *Parameter example:*
-                  ``identity='T'
-
-                *Parameter example:*
-                  ``identity='long_name=Cell Area'``
-
-                *Parameter example:*
-                  ``identity='cellmeasure1'``
-
-                *Parameter example:*
-                  ``identity='measure:area'``
-
-                *Parameter example:*
-                  ``identity=cf.eq('time')'``
-
-                *Parameter example:*
-                  ``identity=re.compile('^lat')``
-
-            default: optional
-                Return the value of the *default* parameter if the data
-                axes have not been set.
-
-                {{default Exception}}
-
-        :Returns:
-
-            `tuple`
-                The keys of the domain axis constructs spanned by the data.
-
-        **Examples:**
-
-        >>> d = cf.example_field(7).domain
-        >>> print(d)
-        Dimension coords: time(3) = [1979-05-01 12:00:00, 1979-05-02 12:00:00, 1979-05-03 12:00:00] gregorian
-                        : air_pressure(1) = [850.0] hPa
-                        : grid_latitude(4) = [0.44, ..., -0.88] degrees
-                        : grid_longitude(5) = [-1.18, ..., 0.58] degrees
-        Auxiliary coords: latitude(grid_latitude(4), grid_longitude(5)) = [[52.4243, ..., 51.1163]] degrees_north
-                        : longitude(grid_latitude(4), grid_longitude(5)) = [[8.0648, ..., 10.9238]] degrees_east
-        Coord references: grid_mapping_name:rotated_latitude_longitude
-        >>> print(d.constructs)
-        Constructs:
-        {'auxiliarycoordinate0': <CF AuxiliaryCoordinate: latitude(4, 5) degrees_north>,
-         'auxiliarycoordinate1': <CF AuxiliaryCoordinate: longitude(4, 5) degrees_east>,
-         'coordinatereference0': <CF CoordinateReference: grid_mapping_name:rotated_latitude_longitude>,
-         'dimensioncoordinate0': <CF DimensionCoordinate: time(3) days since 1979-1-1 gregorian>,
-         'dimensioncoordinate1': <CF DimensionCoordinate: air_pressure(1) hPa>,
-         'dimensioncoordinate2': <CF DimensionCoordinate: grid_latitude(4) degrees>,
-         'dimensioncoordinate3': <CF DimensionCoordinate: grid_longitude(5) degrees>,
-         'domainaxis0': <CF DomainAxis: size(3)>,
-         'domainaxis1': <CF DomainAxis: size(1)>,
-         'domainaxis2': <CF DomainAxis: size(4)>,
-         'domainaxis3': <CF DomainAxis: size(5)>}
-        >>> d.get_data_axes('grid_latitude')
-        ('domainaxis2',)
-        >>> d.get_data_axes('latitude')
-        ('domainaxis2', 'domainaxis3')
-
-        """
-        key = self.construct(identity, key=True, default=None)
-        if key is None:
-            return self.construct_key(identity, default=default)
-
-        return super().get_data_axes(key=key, default=default)
-
     def identity(self, default="", strict=False, relaxed=False, nc_only=False):
         """Return the canonical identity.
 
@@ -552,7 +308,7 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
 
                 The identity.
 
-        **Examples:**
+        **Examples**
 
         >>> f.properties()
         {'foo': 'bar',
@@ -633,11 +389,11 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
         The identities comprise:
 
         * The "id" attribute, preceded by ``'id%'``.
-        * The ``cf_role`` property, preceeded by ``'cf_role='``.
-        * The ``long_name`` property, preceeded by ``'long_name='``.
-        * All other properties, preceeded by the property name and a
+        * The ``cf_role`` property, preceded by ``'cf_role='``.
+        * The ``long_name`` property, preceded by ``'long_name='``.
+        * All other properties, preceded by the property name and a
           equals e.g. ``'foo=bar'``.
-        * The netCDF variable name, preceeded by ``'ncvar%'``.
+        * The netCDF variable name, preceded by ``'ncvar%'``.
 
         .. versionadded:: (cfdm) 1.9.0.0
 
@@ -648,7 +404,7 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
             `list`
                 The identities.
 
-        **Examples:**
+        **Examples**
 
         >>> d = {{package}}.Domain()
         >>> d.set_properties({'foo': 'bar',
@@ -675,42 +431,45 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
         """Create indices that define a subspace of the domain
         construct.
 
-        The indices returned by this method be used to create the subspace
-        by passing them to the `subspace` method of the original domain
-        construct.
+        The indices returned by this method be used to create the
+        subspace by passing them to the `subspace` method of the
+        original domain construct.
 
         The subspace is defined by identifying indices based on the
         metadata constructs.
 
-        Metadata constructs are selected conditions are specified on their
-        data. Indices for subspacing are then automatically inferred from
-        where the conditions are met.
+        Metadata constructs are selected conditions are specified on
+        their data. Indices for subspacing are then automatically
+        inferred from where the conditions are met.
 
-        Metadata constructs and the conditions on their data are defined
-        by keyword parameters.
+        Metadata constructs and the conditions on their data are
+        defined by keyword parameters.
 
-        * Any domain axes that have not been identified remain unchanged.
+        * Any domain axes that have not been identified remain
+          unchanged.
 
         * Multiple domain axes may be subspaced simultaneously, and it
           doesn't matter which order they are specified in.
 
         * Explicit indices may also be assigned to a domain axis
-          identified by a metadata construct, with either a Python `slice`
-          object, or a sequence of integers or booleans.
+          identified by a metadata construct, with either a Python
+          `slice` object, or a sequence of integers or booleans.
 
-        * For a dimension that is cyclic, a subspace defined by a slice or
-          by a `Query` instance is assumed to "wrap" around the edges of
-          the data.
+        * For a dimension that is cyclic, a subspace defined by a
+          slice or by a `Query` instance is assumed to "wrap" around
+          the edges of the data.
 
         * Conditions may also be applied to multi-dimensional metadata
-          constructs. The "compress" mode is still the default mode (see
-          the positional arguments), but because the indices may not be
-          acting along orthogonal dimensions, some missing data may still
-          need to be inserted into the field construct's data.
+          constructs. The "compress" mode is still the default mode
+          (see the positional arguments), but because the indices may
+          not be acting along orthogonal dimensions, some missing data
+          may still need to be inserted into the field construct's
+          data.
 
         .. versionadded:: 3.11.0
 
-        .. seealso:: `subspace`, `where`, `__getitem__`, `__setitem__`
+        .. seealso:: `subspace`, `where`, `__getitem__`,
+                     `__setitem__`, `cf.Field.indices`
 
         :Parameters:
 
@@ -718,30 +477,30 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
                 There are two modes of operation, each of which provides
                 indices for a different type of subspace:
 
-                ==============  ==========================================
+                ==============  ======================================
                 *mode*          Description
-                ==============  ==========================================
-                ``'compress'``  Return indices that identify only the
-                                requested locations.
+                ==============  ======================================
+                ``'compress'``  This is the default mode. Unselected
+                                locations are removed to create the
+                                returned subspace. Note that if a
+                                multi-dimensional metadata construct
+                                is being used to define the indices
+                                then some missing data may still be
+                                inserted at unselected locations.
 
-                                This is the default mode.
-
-                                Note that if a multi-dimensional metadata
-                                construct is being used to define the
-                                indices then some unrequested locations
-                                may also be selected.
-
-                ``'envelope'``  The returned subspace is the smallest that
-                                contains all of the requested locations.
-                ==============  ==========================================
+                ``'envelope'``  The returned subspace is the smallest
+                                that contains all of the selected
+                                indices.
+                ==============  ======================================
 
             kwargs: *optional*
-                A keyword name is an identity of a metadata construct, and
-                the keyword value provides a condition for inferring
-                indices that apply to the dimension (or dimensions)
-                spanned by the metadata construct's data. Indices are
-                created that select every location for which the metadata
-                construct's data satisfies the condition.
+                A keyword name is an identity of a metadata construct,
+                and the keyword value provides a condition for
+                inferring indices that apply to the dimension (or
+                dimensions) spanned by the metadata construct's
+                data. Indices are created that select every location
+                for which the metadata construct's data satisfies the
+                condition.
 
         :Returns:
 
@@ -749,7 +508,7 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
                 A dictionary of indices, keyed by the domain axis
                 construct identifiers to which they apply.
 
-        **Examples:**
+        **Examples**
 
         >>> d = cf.example_field(0).domain
         >>> print(d)
@@ -799,15 +558,10 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
         else:
             raise ValueError(f"Invalid value for 'mode' argument: {mode[0]!r}")
 
-        # ------------------------------------------------------------
         # Get the indices for every domain axis in the domain, without
         # any auxiliary masks.
-        # ------------------------------------------------------------
-        domain_indices = self._indices(mode, None, False, **kwargs)
+        domain_indices = self._indices(mode, None, False, kwargs)
 
-        # ------------------------------------------------------------
-        # Return the indices
-        # ------------------------------------------------------------
         return domain_indices["indices"]
 
     def match_by_construct(self, *identities, OR=False, **conditions):
@@ -833,16 +587,16 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
                 ``'method:mean'``) then it will only be compared with the
                 most recently applied cell method operation.
 
-                Alternatively, one or more cell method constucts may be
-                identified in a single string with a CF-netCDF cell
+                Alternatively, one or more cell method constructs may
+                be identified in a single string with a CF-netCDF cell
                 methods-like syntax for describing both the collapse
                 dimensions, the collapse method, and any cell method
-                construct qualifiers. If N cell methods are described in
-                this way then they will collectively identify the N most
-                recently applied cell method operations. For example,
-                ``'T: maximum within years T: mean over years'`` will be
-                compared with the most two most recently applied cell
-                method operations.
+                construct qualifiers. If N cell methods are described
+                in this way then they will collectively identify the N
+                most recently applied cell method operations. For
+                example, ``'T: maximum within years T: mean over
+                years'`` will be compared with the most two most
+                recently applied cell method operations.
 
                 *Parameter example:*
                   ``identity='latitude'``
@@ -914,10 +668,10 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
         :Returns:
 
             `bool`
-                Whether or not the domain construct contains the specfied
-                metadata constructs.
+                Whether or not the domain construct contains the
+                specified metadata constructs.
 
-        **Examples:**
+        **Examples**
 
         >>> d = cf.example_field(0).domain
         >>> print(d)
@@ -1022,7 +776,7 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
             `Field`
                 The rolled field.
 
-        **Examples:**
+        **Examples**
 
         Roll the data of the "X" axis one elements to the right:
 
@@ -1033,7 +787,8 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
         >>> f.roll('X', -3)
 
         """
-        # TODODASK - allow multiple roll axes
+        # TODODASK: Consider allowing multiple roll axes, now that
+        #           Data supports them.
 
         axis = self.domain_axis(
             axis,
@@ -1140,7 +895,7 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
                 whether or not it is possible to create specified
                 subspace.
 
-        **Examples:**
+        **Examples**
 
         >>> d = cf.example_field(0).domain
         >>> print(d)
@@ -1163,11 +918,6 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
                        : time(1) = [2019-01-01 00:00:00]
 
         """
-        logger.debug(
-            f"{self.__class__.__name__}.subspace\n"
-            f"  input kwargs = {kwargs}"
-        )  # pragma: no cover
-
         test = False
         if "test" in mode:
             mode = list(mode)
@@ -1205,12 +955,6 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
             tuple(shape), tuple(indices2), cyclic=True
         )
 
-        logger.debug(
-            f"  axes           = {axes!r}\n"
-            f"  parsed indices = {indices!r}\n"
-            f"  roll           = {roll!r}"
-        )  # pragma: no cover
-
         if roll:
             new = self
             cyclic_axes = self.cyclic()
@@ -1231,19 +975,7 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
         # Set sizes of domain axes
         # ------------------------------------------------------------
         domain_axes = new.domain_axes(todict=True)
-        for axis, index in zip(axes, indices):
-            if isinstance(index, slice):
-                old_size = domain_axes[axis].get_size()
-                start, stop, step = index.indices(old_size)
-                size = abs((stop - start) / step)
-                int_size = round(size)
-                if size > int_size:
-                    size = int_size + 1
-                else:
-                    size = int_size
-            else:
-                size = np.size(index)
-
+        for axis, size in zip(axes, indices_shape(indices, shape)):
             domain_axes[axis].set_size(size)
 
         # ------------------------------------------------------------
@@ -1270,10 +1002,10 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
         """Permute the data axes of the metadata constructs.
 
         Each metadata construct has its data axis order changed to the
-        relative ordering defined by the *axes* parameter. For instance,
-        if the given *axes* are ``['X', 'Z', 'Y']`` then a metadata
-        construct whose data axis order is ('Y', 'X') will be tranposed to
-        have data order ('X', 'Y').
+        relative ordering defined by the *axes* parameter. For
+        instance, if the given *axes* are ``['X', 'Z', 'Y']`` then a
+        metadata construct whose data axis order is ``('Y', 'X')``
+        will be transposed to have data order ``('X', 'Y')``.
 
         .. versionadded:: 3.11.0
 
@@ -1307,7 +1039,7 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
                 The domain construct with transposed constructs, or `None`
                 if the operation was in-place.
 
-        **Examples:**
+        **Examples**
 
         >>> d = cf.example_field(7).domain
         >>> print(d)
