@@ -1,25 +1,22 @@
 import logging
 
-import cfdm
-
-from .units import Units
-
-from .functions import bounds_combination_mode
+from cfdm.core import DocstringRewriteMeta
 
 from .constants import (
-    formula_terms_standard_names,
-    formula_terms_max_dimensions,
-    formula_terms_units,
     formula_terms_computed_standard_names,
     formula_terms_D1,
+    formula_terms_max_dimensions,
+    formula_terms_standard_names,
+    formula_terms_units,
 )
-
 from .docstring import _docstring_substitution_definitions
+from .functions import bounds_combination_mode
+from .units import Units
 
 logger = logging.getLogger(__name__)
 
 
-class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
+class FormulaTerms(metaclass=DocstringRewriteMeta):
     """Functions for computing non-parametric vertical coordinates from
     the formula defined by a coordinate reference construct.
 
@@ -67,13 +64,13 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         return _docstring_substitution_definitions
 
     def __docstring_package_depth__(self):
-        """Return the package depth for {{package}} docstring
+        """Return the package depth for "package" docstring
         substitutions.
 
         See `_docstring_package_depth` for details.
 
         """
-        return 1
+        return 0
 
     # ----------------------------------------------------------------
     # Private methods
@@ -138,7 +135,7 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         if units is None:
             raise ValueError(
                 "Can't calculate non-parametric vertical coordinates: "
-                "{!r} is not a valid term".format(term)
+                f"{term!r} is not a valid term"
             )
 
         units = Units(units)
@@ -151,9 +148,7 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
 
         if var is not None:
             logger.detail(
-                "Formula term {!r}:\n{}".format(
-                    term, var.dump(display=False, _level=1)
-                )
+                f"Formula term {term!r}:\n{var.dump(display=False, _level=1)}"
             )  # pragma: no cover
 
             valid_standard_names = formula_terms_standard_names[standard_name][
@@ -168,50 +163,43 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
                     and vsn not in valid_standard_names
                     and len(valid_standard_names) > 1
                 ):
+                    expected_names = ", ".join(
+                        repr(x) for x in valid_standard_names
+                    )
                     raise ValueError(
                         "Can't calculate non-parametric vertical coordinates: "
-                        "{!r} term {!r} has no standard name. "
-                        "Expected one of {}".format(
-                            term,
-                            var,
-                            ", ".join(repr(x) for x in valid_standard_names),
-                        )
+                        f"{term!r} term {var!r} has no standard name. "
+                        f"Expected one of {expected_names}"
                     )
             elif vsn not in valid_standard_names:
+                expected_names = ", ".join(
+                    repr(x) for x in valid_standard_names
+                )
                 raise ValueError(
                     "Can't calculate non-parametric vertical coordinates: "
-                    "{!r} term {!r} has invalid "
-                    "standard name: {!r}. Expected one of {}".format(
-                        term,
-                        var,
-                        vsn,
-                        ", ".join(repr(x) for x in valid_standard_names),
-                    )
+                    f"{term!r} term {var!r} has invalid standard name: "
+                    f"{vsn!r}. Expected one of {expected_names}"
                 )
 
             if var.ndim > formula_terms_max_dimensions[standard_name][term]:
                 raise ValueError(
                     "Can't calculate non-parametric vertical coordinates: "
-                    "{!r} term {!r} has incorrect "
-                    "number of dimensions. Expected at most {}".format(
-                        term, var, var.ndim
-                    )
+                    f"{term!r} term {var!r} has incorrect "
+                    f"number of dimensions. Expected at most {var.ndim}"
                 )
 
             if not var.Units.equivalent(units):
                 raise ValueError(
                     "Can't calculate non-parametric vertical coordinates: "
-                    "{!r} term {!r} has incorrect units: {!r} "
-                    "Expected units equivalent to {!r}".format(
-                        term, var, var.Units, units
-                    )
+                    f"{term!r} term {var!r} has incorrect units: "
+                    f"{var.Units!r}. Expected units equivalent to {units!r}"
                 )
         else:
             if not default_to_zero:
                 raise ValueError(
                     "Can't calculate non-parametric vertical coordinates: "
-                    "No {!r} term domain ancillary construct and "
-                    "default_to_zero=False".format(term)
+                    f"No {term!r} term domain ancillary construct and "
+                    "default_to_zero=False"
                 )
             # ----------------------------------------------------
             # Create a default zero-valued domain ancillary
@@ -226,9 +214,8 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
                 var.set_bounds(bounds)
 
             logger.detail(
-                "Formula term {!r} (default):\n{}".format(
-                    term, var.dump(display=False, _level=1)
-                )
+                f"Formula term {term!r} (default):\n"
+                f"{var.dump(display=False, _level=1)}"
             )  # pragma: no cover
 
         return var, key
@@ -238,8 +225,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Find the standard name of the computed non-parametric
         vertical coordinates.
 
-        {{formula terms links}}
-
         .. versionadded:: 3.8.0
 
         :Parameters:
@@ -270,7 +255,7 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
             # There is a unique computed standard name for this formula
             # ------------------------------------------------------------
             logger.detail(
-                "computed_standard_name: {!r}".format(computed_standard_name)
+                f"computed_standard_name: {computed_standard_name!r}"
             )  # pragma: no cover
 
             return computed_standard_name
@@ -367,7 +352,7 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
             axis = f.get_data_axes(key)
             break
 
-        logger.detail("Vertical axis: {!r}".format(axis))  # pragma: no cover
+        logger.detail(f"Vertical axis: {axis!r}")  # pragma: no cover
 
         return axis
 
@@ -417,8 +402,8 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
             if not set(eta_axes).issuperset(depth_axes):
                 raise ValueError(
                     "Can't calculate non-parametric coordinates: "
-                    "'depth' term {!r} axes must be a subset of "
-                    "'eta' term {!r} axes.".format(depth, eta)
+                    f"'depth' term {depth!r} axes must be a subset of "
+                    f"'eta' term {eta!r} axes."
                 )
 
             eta_axes2 = depth_axes
@@ -432,10 +417,8 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
             eta_axes = eta_axes2
 
         logger.debug(
-            "Transposed domain ancillary 'eta': {!r}\n"
-            "Transposed domain ancillary 'eta' axes: {!r}".format(
-                eta, eta_axes
-            )
+            f"Transposed domain ancillary 'eta': {eta!r}\n"
+            f"Transposed domain ancillary 'eta' axes: {eta_axes!r}"
         )  # pragma: no cover
 
         return eta, eta_axes
@@ -506,7 +489,7 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
             computed_axes = tuple([computed_axes[i] for i in iaxes])
 
         logger.detail(
-            "Non-parametric coordinate axes: {!r}".format(computed_axes)
+            f"Non-parametric coordinate axes: {computed_axes!r}"
         )  # pragma: no cover
 
         return computed, computed_axes
@@ -554,8 +537,8 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         if units != ref_units:
             if not units.equivalent(ref_units):
                 raise ValueError(
-                    "Terms {!r} and {!r} have incompatible units: "
-                    "{!r}, {!r} ".format(ref_term2, term, ref_units, units)
+                    f"Terms {ref_term2!r} and {term!r} have incompatible "
+                    f"units: {ref_units!r}, {units!r}"
                 )
 
             var = var.copy()
@@ -573,8 +556,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         s-coordinate, the ocean_sigma over z coordinate, and the ocean
         double sigma coordinate.
 
-        {{formula terms links}}
-
         .. versionadded:: 3.8.0
 
         :Parameters:
@@ -632,8 +613,8 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
                 # been ensured by `_domain_ancillary_term`
                 if strict:
                     raise ValueError(
-                        "{!r} term {!r} has invalid "
-                        "standard name: {!r}".format(term, var, standard_name)
+                        f"{term!r} term {var!r} has invalid "
+                        f"standard name: {standard_name!r}"
                     )
 
         if strict and not indices:
@@ -641,7 +622,7 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
                 "Terms {} have no standard names. "
                 "See Appendix D: Parametric Vertical Coordinates "
                 "of the CF conventions.".format(
-                    ", ".join(repr(term) for term in kwargs),
+                    ", ".join(repr(term) for term in kwargs)
                 )
             )
 
@@ -650,7 +631,7 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
                 "Terms {} have incompatible standard names. "
                 "See Appendix D: Parametric Vertical Coordinates "
                 "of the CF conventions.".format(
-                    ", ".join(repr(term) for term in kwargs),
+                    ", ".join(repr(term) for term in kwargs)
                 )
             )
 
@@ -681,8 +662,8 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         if var.size != 1 or var.dtype.kind != "i":
             raise ValueError(
                 "Can't calculate non-parametric vertical coordinates: "
-                "{!r} term {!r} doen't contain exactly one "
-                "integer value".format(term, var)
+                f"{term!r} term {var!r} doen't contain exactly one "
+                "integer value"
             )
 
     # ----------------------------------------------------------------
@@ -695,8 +676,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         atmosphere_ln_pressure_coordinate parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -776,8 +755,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         atmosphere_sigma_coordinate parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -873,8 +850,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         atmosphere_hybrid_sigma_pressure_coordinate parametric
         coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -1004,8 +979,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         atmosphere_hybrid_height_coordinate parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -1102,8 +1075,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         atmosphere_sleve_coordinate parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -1257,8 +1228,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         ocean_sigma_coordinate parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -1362,8 +1331,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         ocean_s_coordinate parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -1504,8 +1471,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         ocean_s_coordinate_g1 parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -1633,8 +1598,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         ocean_s_coordinate_g2 parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -1762,8 +1725,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         ocean_sigma_z_coordinate parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -1912,8 +1873,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
         """Compute non-parametric vertical coordinates from
         ocean_double_sigma_coordinate parametric coordinates.
 
-        {{formula terms links}}
-
         .. note:: The vertical axis is the last (rightmost) dimension of
                   the returned computed non-parametric vertical
                   coordinates, if applicable.
@@ -2066,8 +2025,6 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
     ):
         """Compute non-parametric vertical coordinates.
 
-        {{formula terms links}}
-
         Dimensional vertical auxiliary coordinate values are computed from
         parametric vertical coordinate values (usually dimensionless) and
         associated domain ancillary constructs, as defined by the formula
@@ -2139,7 +2096,7 @@ class FormulaTerms(metaclass=cfdm.core.DocstringRewriteMeta):
 
         if standard_name is not None:
             logger.detail(
-                "standard_name: {!r}".format(standard_name)
+                f"standard_name: {standard_name!r}"
             )  # pragma: no cover
 
             if standard_name in cls.standard_names:
