@@ -136,7 +136,6 @@ class FieldTest(unittest.TestCase):
         for method in methods:
             message = "method=" + method
             for f in cf.read(getattr(self, method)):
-
                 self.assertTrue(bool(f.data.get_compression_type()), message)
 
                 u = f.uncompress()
@@ -522,6 +521,34 @@ class FieldTest(unittest.TestCase):
                         a.equals(b, rtol=1e-05, atol=1e-08, verbose=2),
                     )
 
+        # Test the remove_vertical_crs keyword
+        f = cf.example_field(1)
+        self.assertTrue(
+            f.has_construct(
+                "standard_name:atmosphere_hybrid_height_coordinate"
+            )
+        )
+        self.assertEqual(len(f.coordinate_references()), 2)
+        self.assertEqual(len(f.domain_ancillaries()), 3)
+
+        u = f.collapse("X: mean")
+        self.assertFalse(
+            u.has_construct(
+                "standard_name:atmosphere_hybrid_height_coordinate"
+            )
+        )
+        self.assertEqual(len(u.coordinate_references()), 1)
+        self.assertEqual(len(u.domain_ancillaries()), 0)
+
+        u = f.collapse("X: mean", remove_vertical_crs=False)
+        self.assertTrue(
+            u.has_construct(
+                "standard_name:atmosphere_hybrid_height_coordinate"
+            )
+        )
+        self.assertEqual(len(u.coordinate_references()), 2)
+        self.assertEqual(len(u.domain_ancillaries()), 2)
+
     def test_Field_all(self):
         f = self.f.copy()
 
@@ -2503,6 +2530,26 @@ class FieldTest(unittest.TestCase):
         h = f.subspace(grid_longitude=np.float64(20))
         self.assertTrue(g.equals(h))
 
+    def test_Field_auxiliary_to_dimension_to_auxiliary(self):
+        f = cf.example_field(0)
+        nd = len(f.dimension_coordinates())
+
+        g = f.dimension_to_auxiliary("latitude")
+        self.assertEqual(len(g.dimension_coordinates()), nd - 1)
+        self.assertEqual(len(g.auxiliary_coordinates()), 1)
+
+        h = g.auxiliary_to_dimension("latitude")
+        self.assertEqual(len(h.dimension_coordinates()), nd)
+        self.assertEqual(len(h.auxiliary_coordinates()), 0)
+        self.assertTrue(h.equals(f))
+        self.assertIsNone(f.dimension_to_auxiliary("Y", inplace=True))
+        self.assertIsNone(g.auxiliary_to_dimension("Y", inplace=True))
+
+        f = cf.read("geometry_1.nc")[0]
+
+        with self.assertRaises(ValueError):
+            f.auxiliary_to_dimension("latitude")
+
 
 if __name__ == "__main__":
     print("Run date:", datetime.datetime.now())
