@@ -15,7 +15,6 @@ class QueryTest(unittest.TestCase):
     f = cf.example_field(1)
 
     def test_Query_contains(self):
-
         c = self.f.dim("X")
         self.assertTrue(
             (
@@ -540,6 +539,69 @@ class QueryTest(unittest.TestCase):
         self.assertNotEqual(x, cf.eq(re.compile(".*RTY$")))
         self.assertNotEqual(x, cf.eq(re.compile("^.*RTY$")))
 
+    def test_Query_set_condition_units(self):
+        q = cf.lt(9)
+        q.set_condition_units("km")
+        self.assertEqual(q.value.Units, cf.Units("km"))
+
+        with self.assertRaises(ValueError):
+            q.set_condition_units("seconds")
+
+        q = cf.lt(9000, units="m")
+        q.set_condition_units("km")
+        self.assertEqual(q.value.Units, cf.Units("km"))
+        self.assertEqual(q.value.array, 9)
+
+        q = cf.lt(9)
+        r = cf.ge(3000, units="m")
+        s = q & r
+        s.set_condition_units("km")
+        self.assertEqual(s._compound[0].value.Units, cf.Units("km"))
+        self.assertEqual(s._compound[1].value.Units, cf.Units("km"))
+        self.assertEqual(s._compound[0].value.array, 9)
+        self.assertEqual(s._compound[1].value.array, 3)
+
+        self.assertEqual(r.value.Units, cf.Units("m"))
+        self.assertEqual(r.value.array, 3000)
+        self.assertEqual(q.value, 9)
+
+    def test_Query_iscontains(self):
+        q = cf.contains(9)
+        self.assertTrue(q.iscontains())
+
+        r = cf.lt(9)
+        self.assertFalse(r.iscontains())
+        self.assertFalse((q | r).iscontains())
+
+    def test_Query__and__(self):
+        q = cf.gt(9)
+        r = cf.lt(11)
+        s = q & r
+        self.assertTrue(s == 10)
+        self.assertFalse(s == 8)
+        with self.assertRaises(AttributeError):
+            s.value
+
+        r = cf.lt(9)
+        s = q & r
+        self.assertEqual(s.value, 9)
+        self.assertFalse(s == 9)
+
+    def test_Query__or__(self):
+        q = cf.eq(9)
+        r = cf.gt(11)
+        s = q | r
+        self.assertTrue(s == 9)
+        self.assertTrue(s == 12)
+        self.assertFalse(s == 10)
+        with self.assertRaises(AttributeError):
+            s.value
+
+        r = cf.gt(9)
+        s = q | r
+        self.assertEqual(s.value, 9)
+        self.assertFalse(s == 8)
+
 
 if __name__ == "__main__":
     print("Run date:", datetime.datetime.now())
