@@ -37,10 +37,7 @@ class ExtraData(dict):
         k.sort()
         return k
 
-    _tolerances = {
-        np.dtype(np.float32): 1e-5,
-        np.dtype(np.float64): 1e-13,
-    }
+    _tolerances = {np.dtype(np.float32): 1e-5, np.dtype(np.float64): 1e-13}
 
     def _cmp_floats(self, a, b, tolerance):
         if a == b:
@@ -97,7 +94,6 @@ class ExtraData(dict):
 
 
 class ExtraDataUnpacker:
-
     _int_types = {4: np.int32, 8: np.int64}
     _float_types = {4: np.float32, 8: np.float64}
 
